==> fief_server-0.29.0.tar.gz: fief_server-0.29.0/README.md <==
<p align="center">
  <img src="https://raw.githubusercontent.com/fief-dev/.github/main/logos/logo-full-red.svg?sanitize=true" alt="Fief" width="256">
</p>

<p align="center">
    <em>Users and authentication management SaaS</em>
</p>

<p align="center">
    <a href="https://polar.sh/fief-dev">
    <picture>
      <source media="(prefers-color-scheme: dark)" srcset="https://polar.sh/embed/subscribe.svg?org=fief-dev&darkmode=1">
      <img alt="Subscribe" src="https://polar.sh/embed/subscribe.svg?org=fief-dev">
    </picture>
    </a>
</p>

## Getting started

* Official website: [https://www.fief.dev](https://www.fief.dev)
* Documentation: [https://docs.fief.dev](https://docs.fief.dev)

## Support us

<a href="https://polar.sh/fief-dev/subscriptions"><picture><source media="(prefers-color-scheme: dark)" srcset="https://polar.sh/embed/tiers.svg?org=fief-dev&darkmode"><img alt="Subscription Tiers on Polar" src="https://polar.sh/embed/tiers.svg?org=fief-dev"></picture></a>

## Contributing

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-28-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

All contributions to improve the project are welcome! In particular, bug and documentation fixes are really appreciated.

For new features and larger improvements, we kindly ask you to [**open a discussion first**](https://github.com/orgs/fief-dev/discussions/new?category=ideas) about your idea, what motivates it and how you plan to implement it **before you start working**. It'll avoid frustration on both sides if we decide not to integrate your code in the project.

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/shrike71"><img src="https://avatars.githubusercontent.com/u/748514?v=4?s=100" width="100px;" alt="shrike71"/><br /><sub><b>shrike71</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Ashrike71" title="Bug reports">🐛</a> <a href="#ideas-shrike71" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://growthengineai.com"><img src="https://avatars.githubusercontent.com/u/4735784?v=4?s=100" width="100px;" alt="trisongz"/><br /><sub><b>trisongz</b></sub></a><br /><a href="#example-trisongz" title="Examples">💡</a> <a href="#ideas-trisongz" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/davidbrochart"><img src="https://avatars.githubusercontent.com/u/4711805?v=4?s=100" width="100px;" alt="David Brochart"/><br /><sub><b>David Brochart</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=davidbrochart" title="Documentation">📖</a> <a href="https://github.com/fief-dev/fief/commits?author=davidbrochart" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/paolodina"><img src="https://avatars.githubusercontent.com/u/1157401?v=4?s=100" width="100px;" alt="Paolo Dina"/><br /><sub><b>Paolo Dina</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Apaolodina" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/duber000"><img src="https://avatars.githubusercontent.com/u/12467861?v=4?s=100" width="100px;" alt="duber000"/><br /><sub><b>duber000</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=duber000" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://theraloss.com"><img src="https://avatars.githubusercontent.com/u/6277291?v=4?s=100" width="100px;" alt="Danilo Polani"/><br /><sub><b>Danilo Polani</b></sub></a><br /><a href="#translation-danilopolani" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ChuckMoe"><img src="https://avatars.githubusercontent.com/u/25569291?v=4?s=100" width="100px;" alt="Moritz"/><br /><sub><b>Moritz</b></sub></a><br /><a href="#translation-ChuckMoe" title="Translation">🌍</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/plpsanchez"><img src="https://avatars.githubusercontent.com/u/45295173?v=4?s=100" width="100px;" alt="plpsanchez"/><br /><sub><b>plpsanchez</b></sub></a><br /><a href="#translation-plpsanchez" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/WilliamMayor"><img src="https://avatars.githubusercontent.com/u/403126?v=4?s=100" width="100px;" alt="William Mayor"/><br /><sub><b>William Mayor</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=WilliamMayor" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://ruipoliveira.github.io/"><img src="https://avatars.githubusercontent.com/u/10942886?v=4?s=100" width="100px;" alt="Rui Oliveira"/><br /><sub><b>Rui Oliveira</b></sub></a><br /><a href="#translation-ruipoliveira" title="Translation">🌍</a> <a href="https://github.com/fief-dev/fief/commits?author=ruipoliveira" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://jimscope.is-a.dev"><img src="https://avatars.githubusercontent.com/u/27647007?v=4?s=100" width="100px;" alt="Jimmy Angel Pérez Díaz"/><br /><sub><b>Jimmy Angel Pérez Díaz</b></sub></a><br /><a href="#translation-JimScope" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://pasteman.dev/"><img src="https://avatars.githubusercontent.com/u/5132385?v=4?s=100" width="100px;" alt="Michał Rosiak"/><br /><sub><b>Michał Rosiak</b></sub></a><br /><a href="#translation-michaldev" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://www.olimcc.com"><img src="https://avatars.githubusercontent.com/u/842983?v=4?s=100" width="100px;" alt="olimcc"/><br /><sub><b>olimcc</b></sub></a><br /><a href="#security-olimcc" title="Security">🛡️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://joehamman.com"><img src="https://avatars.githubusercontent.com/u/2443309?v=4?s=100" width="100px;" alt="Joe Hamman"/><br /><sub><b>Joe Hamman</b></sub></a><br /><a href="#security-jhamman" title="Security">🛡️</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/zfei"><img src="https://avatars.githubusercontent.com/u/1736058?v=4?s=100" width="100px;" alt="zfei"/><br /><sub><b>zfei</b></sub></a><br /><a href="#translation-zfei" title="Translation">🌍</a> <a href="https://github.com/fief-dev/fief/commits?author=zfei" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://bartoszmagiera.live/"><img src="https://avatars.githubusercontent.com/u/28759224?v=4?s=100" width="100px;" alt="Bartosz Magiera"/><br /><sub><b>Bartosz Magiera</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=bartosz121" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://razalt.com"><img src="https://avatars.githubusercontent.com/u/10688199?v=4?s=100" width="100px;" alt="oaltun"/><br /><sub><b>oaltun</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=oaltun" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://cesarsmaniotto.dev"><img src="https://avatars.githubusercontent.com/u/7607534?v=4?s=100" width="100px;" alt="Cesar Smaniotto Júnior"/><br /><sub><b>Cesar Smaniotto Júnior</b></sub></a><br /><a href="#translation-csmaniottojr" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/rotil"><img src="https://avatars.githubusercontent.com/u/42150485?v=4?s=100" width="100px;" alt="rotil"/><br /><sub><b>rotil</b></sub></a><br /><a href="#security-rotil" title="Security">🛡️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/bingyulee"><img src="https://avatars.githubusercontent.com/u/4936030?v=4?s=100" width="100px;" alt="李秉祐"/><br /><sub><b>李秉祐</b></sub></a><br /><a href="#translation-bingyulee" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://dubinets.io"><img src="https://avatars.githubusercontent.com/u/3114081?v=4?s=100" width="100px;" alt="Lev Dubinets"/><br /><sub><b>Lev Dubinets</b></sub></a><br /><a href="#financial-ldub" title="Financial">💵</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://meltingrocks.com/"><img src="https://avatars.githubusercontent.com/u/37904?v=4?s=100" width="100px;" alt="Mathieu Virbel"/><br /><sub><b>Mathieu Virbel</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Atito" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/corv89"><img src="https://avatars.githubusercontent.com/u/7198687?v=4?s=100" width="100px;" alt="corv89"/><br /><sub><b>corv89</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Acorv89" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/yaroslaff"><img src="https://avatars.githubusercontent.com/u/4574588?v=4?s=100" width="100px;" alt="Yaroslav Polyakov"/><br /><sub><b>Yaroslav Polyakov</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=yaroslaff" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ScottFred"><img src="https://avatars.githubusercontent.com/u/1937793?v=4?s=100" width="100px;" alt="Scott Fredericksen"/><br /><sub><b>Scott Fredericksen</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=ScottFred" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://robertbabaev.tech/home"><img src="https://avatars.githubusercontent.com/u/32110856?v=4?s=100" width="100px;" alt="Robert Babaev"/><br /><sub><b>Robert Babaev</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=ApprenticeofEnder" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/BlackIsBlack"><img src="https://avatars.githubusercontent.com/u/39253172?v=4?s=100" width="100px;" alt="Cameron"/><br /><sub><b>Cameron</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3ABlackIsBlack" title="Bug reports">🐛</a> <a href="https://github.com/fief-dev/fief/commits?author=BlackIsBlack" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/i-am-mike-davis"><img src="https://avatars.githubusercontent.com/u/139306671?v=4?s=100" width="100px;" alt="i-am-mike-davis"/><br /><sub><b>i-am-mike-davis</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=i-am-mike-davis" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

## Development

To get started quickly, we recommend you to use [GitHub Codespaces](https://github.com/features/codespaces). We have a complete configuration allowing you to start working on Fief right away, including pre-configured PostgreSQL and Redis servers.

<p align="center">
<a href="https://github.com/codespaces/new?hide_repo_select=true&ref=main&repo=444125382"><img src="https://github.com/codespaces/badge.svg" alt="Open in GitHub Codespaces"></a>
</p>

When the Codespace is built, an admin user is automatically created.

> **Admin user credentials**
>
> Email: `anne@bretagne.duchy`
>
> Password: `herminetincture`

Run the Fief server in development mode with the following command:

```sh
hatch run dev.server.start
```

The worker can also be started with the following command:

```sh
hatch run dev.worker.start
```

## License

Fief is [fair-code](http://faircode.io) distributed under [**Elastic License 2.0 (ELv2)**](https://github.com/fief-dev/fief/blob/main/LICENSE.md).

==> fief_server-0.30.0.tar.gz: fief_server-0.30.0/README.md <==
<p align="center">
  <img src="https://raw.githubusercontent.com/fief-dev/.github/main/logos/logo-full-red.svg?sanitize=true" alt="Fief" width="256">
</p>

<p align="center">
    <em>Users and authentication management SaaS</em>
</p>

> [!IMPORTANT]
> Fief, as you know it today, is wrapping up its current chapter.
> We're working on a completely new and exciting vision for the future!
>
> This means we won't be adding new features or fixing bugs in this codebase anymore.
> Thank you so much for being part of the journey so far — your support has meant the world to us.
>
> **Stay tuned — we can't wait to show you what's next! 🚀**

## Getting started

- Official website: [https://www.fief.dev](https://www.fief.dev)
- Documentation: [https://docs.fief.dev](https://docs.fief.dev)

## Contributing

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->

[![All Contributors](https://img.shields.io/badge/all_contributors-28-orange.svg?style=flat-square)](#contributors-)

<!-- ALL-CONTRIBUTORS-BADGE:END -->

All contributions to improve the project are welcome! In particular, bug and documentation fixes are really appreciated.

For new features and larger improvements, we kindly ask you to [**open a discussion first**](https://github.com/orgs/fief-dev/discussions/new?category=ideas) about your idea, what motivates it and how you plan to implement it **before you start working**. It'll avoid frustration on both sides if we decide not to integrate your code in the project.

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/shrike71"><img src="https://avatars.githubusercontent.com/u/748514?v=4?s=100" width="100px;" alt="shrike71"/><br /><sub><b>shrike71</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Ashrike71" title="Bug reports">🐛</a> <a href="#ideas-shrike71" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://growthengineai.com"><img src="https://avatars.githubusercontent.com/u/4735784?v=4?s=100" width="100px;" alt="trisongz"/><br /><sub><b>trisongz</b></sub></a><br /><a href="#example-trisongz" title="Examples">💡</a> <a href="#ideas-trisongz" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/davidbrochart"><img src="https://avatars.githubusercontent.com/u/4711805?v=4?s=100" width="100px;" alt="David Brochart"/><br /><sub><b>David Brochart</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=davidbrochart" title="Documentation">📖</a> <a href="https://github.com/fief-dev/fief/commits?author=davidbrochart" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/paolodina"><img src="https://avatars.githubusercontent.com/u/1157401?v=4?s=100" width="100px;" alt="Paolo Dina"/><br /><sub><b>Paolo Dina</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Apaolodina" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/duber000"><img src="https://avatars.githubusercontent.com/u/12467861?v=4?s=100" width="100px;" alt="duber000"/><br /><sub><b>duber000</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=duber000" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://theraloss.com"><img src="https://avatars.githubusercontent.com/u/6277291?v=4?s=100" width="100px;" alt="Danilo Polani"/><br /><sub><b>Danilo Polani</b></sub></a><br /><a href="#translation-danilopolani" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ChuckMoe"><img src="https://avatars.githubusercontent.com/u/25569291?v=4?s=100" width="100px;" alt="Moritz"/><br /><sub><b>Moritz</b></sub></a><br /><a href="#translation-ChuckMoe" title="Translation">🌍</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/plpsanchez"><img src="https://avatars.githubusercontent.com/u/45295173?v=4?s=100" width="100px;" alt="plpsanchez"/><br /><sub><b>plpsanchez</b></sub></a><br /><a href="#translation-plpsanchez" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/WilliamMayor"><img src="https://avatars.githubusercontent.com/u/403126?v=4?s=100" width="100px;" alt="William Mayor"/><br /><sub><b>William Mayor</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=WilliamMayor" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://ruipoliveira.github.io/"><img src="https://avatars.githubusercontent.com/u/10942886?v=4?s=100" width="100px;" alt="Rui Oliveira"/><br /><sub><b>Rui Oliveira</b></sub></a><br /><a href="#translation-ruipoliveira" title="Translation">🌍</a> <a href="https://github.com/fief-dev/fief/commits?author=ruipoliveira" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://jimscope.is-a.dev"><img src="https://avatars.githubusercontent.com/u/27647007?v=4?s=100" width="100px;" alt="Jimmy Angel Pérez Díaz"/><br /><sub><b>Jimmy Angel Pérez Díaz</b></sub></a><br /><a href="#translation-JimScope" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://pasteman.dev/"><img src="https://avatars.githubusercontent.com/u/5132385?v=4?s=100" width="100px;" alt="Michał Rosiak"/><br /><sub><b>Michał Rosiak</b></sub></a><br /><a href="#translation-michaldev" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://www.olimcc.com"><img src="https://avatars.githubusercontent.com/u/842983?v=4?s=100" width="100px;" alt="olimcc"/><br /><sub><b>olimcc</b></sub></a><br /><a href="#security-olimcc" title="Security">🛡️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://joehamman.com"><img src="https://avatars.githubusercontent.com/u/2443309?v=4?s=100" width="100px;" alt="Joe Hamman"/><br /><sub><b>Joe Hamman</b></sub></a><br /><a href="#security-jhamman" title="Security">🛡️</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/zfei"><img src="https://avatars.githubusercontent.com/u/1736058?v=4?s=100" width="100px;" alt="zfei"/><br /><sub><b>zfei</b></sub></a><br /><a href="#translation-zfei" title="Translation">🌍</a> <a href="https://github.com/fief-dev/fief/commits?author=zfei" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://bartoszmagiera.live/"><img src="https://avatars.githubusercontent.com/u/28759224?v=4?s=100" width="100px;" alt="Bartosz Magiera"/><br /><sub><b>Bartosz Magiera</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=bartosz121" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://razalt.com"><img src="https://avatars.githubusercontent.com/u/10688199?v=4?s=100" width="100px;" alt="oaltun"/><br /><sub><b>oaltun</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=oaltun" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://cesarsmaniotto.dev"><img src="https://avatars.githubusercontent.com/u/7607534?v=4?s=100" width="100px;" alt="Cesar Smaniotto Júnior"/><br /><sub><b>Cesar Smaniotto Júnior</b></sub></a><br /><a href="#translation-csmaniottojr" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/rotil"><img src="https://avatars.githubusercontent.com/u/42150485?v=4?s=100" width="100px;" alt="rotil"/><br /><sub><b>rotil</b></sub></a><br /><a href="#security-rotil" title="Security">🛡️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/bingyulee"><img src="https://avatars.githubusercontent.com/u/4936030?v=4?s=100" width="100px;" alt="李秉祐"/><br /><sub><b>李秉祐</b></sub></a><br /><a href="#translation-bingyulee" title="Translation">🌍</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://dubinets.io"><img src="https://avatars.githubusercontent.com/u/3114081?v=4?s=100" width="100px;" alt="Lev Dubinets"/><br /><sub><b>Lev Dubinets</b></sub></a><br /><a href="#financial-ldub" title="Financial">💵</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://meltingrocks.com/"><img src="https://avatars.githubusercontent.com/u/37904?v=4?s=100" width="100px;" alt="Mathieu Virbel"/><br /><sub><b>Mathieu Virbel</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Atito" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/corv89"><img src="https://avatars.githubusercontent.com/u/7198687?v=4?s=100" width="100px;" alt="corv89"/><br /><sub><b>corv89</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3Acorv89" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/yaroslaff"><img src="https://avatars.githubusercontent.com/u/4574588?v=4?s=100" width="100px;" alt="Yaroslav Polyakov"/><br /><sub><b>Yaroslav Polyakov</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=yaroslaff" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ScottFred"><img src="https://avatars.githubusercontent.com/u/1937793?v=4?s=100" width="100px;" alt="Scott Fredericksen"/><br /><sub><b>Scott Fredericksen</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=ScottFred" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://robertbabaev.tech/home"><img src="https://avatars.githubusercontent.com/u/32110856?v=4?s=100" width="100px;" alt="Robert Babaev"/><br /><sub><b>Robert Babaev</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=ApprenticeofEnder" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/BlackIsBlack"><img src="https://avatars.githubusercontent.com/u/39253172?v=4?s=100" width="100px;" alt="Cameron"/><br /><sub><b>Cameron</b></sub></a><br /><a href="https://github.com/fief-dev/fief/issues?q=author%3ABlackIsBlack" title="Bug reports">🐛</a> <a href="https://github.com/fief-dev/fief/commits?author=BlackIsBlack" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/i-am-mike-davis"><img src="https://avatars.githubusercontent.com/u/139306671?v=4?s=100" width="100px;" alt="i-am-mike-davis"/><br /><sub><b>i-am-mike-davis</b></sub></a><br /><a href="https://github.com/fief-dev/fief/commits?author=i-am-mike-davis" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

## Development

To get started quickly, we recommend you to use [GitHub Codespaces](https://github.com/features/codespaces). We have a complete configuration allowing you to start working on Fief right away, including pre-configured PostgreSQL and Redis servers.

<p align="center">
<a href="https://github.com/codespaces/new?hide_repo_select=true&ref=main&repo=444125382"><img src="https://github.com/codespaces/badge.svg" alt="Open in GitHub Codespaces"></a>
</p>

When the Codespace is built, an admin user is automatically created.

> **Admin user credentials**
>
> Email: `anne@bretagne.duchy`
>
> Password: `herminetincture`

Run the Fief server in development mode with the following command:

```sh
hatch run dev.server.start
```

The worker can also be started with the following command:

```sh
hatch run dev.worker.start
```

## License

Fief is [fair-code](http://faircode.io) distributed under [**Elastic License 2.0 (ELv2)**](https://github.com/fief-dev/fief/blob/main/LICENSE.md).
